Module: Wrest
- Defined in:
- lib/wrest/uri.rb,
lib/wrest.rb,
lib/wrest/mappers.rb,
lib/wrest/version.rb,
lib/wrest/response.rb,
lib/wrest/translators.rb,
lib/wrest/uri_template.rb,
lib/wrest/translators/xml.rb,
lib/wrest/mappers/resource.rb,
lib/wrest/translators/json.rb,
lib/wrest/mappers/simple_resource.rb,
lib/wrest/translators/content_types.rb,
lib/wrest/core_ext/string/conversions.rb,
lib/wrest/exceptions/unsupported_content_type_exception.rb
Overview
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Defined Under Namespace
Modules: CoreExt, Mappers, Translators, VERSION Classes: Response, UnsupportedContentTypeException, Uri, UriTemplate
Class Method Summary collapse
Class Method Details
.logger ⇒ Object
27 28 29 |
# File 'lib/wrest.rb', line 27 def self.logger @logger end |
.logger=(logger) ⇒ Object
23 24 25 |
# File 'lib/wrest.rb', line 23 def self.logger=(logger) @logger = logger end |