Module: Wrest::Components
- Defined in:
- lib/wrest/components.rb,
lib/wrest/components/mutators.rb,
lib/wrest/components/translators.rb,
lib/wrest/components/typecast_helpers.rb,
lib/wrest/components/attributes_container.rb,
lib/wrest/components/translators/content_types.rb,
lib/wrest/components/mutators/camel_to_snake_case.rb,
lib/wrest/components/mutators/xml_simple_type_caster.rb
Overview
This mutator undertands how do type casting using the type data embedded in a hash created by deserialising an xml using xml-simple
Defined Under Namespace
Modules: AttributesContainer, Mutators, Translators, TypecastHelpers